Documentation
¶
Index ¶
- func NewStore(opts artifact.StoreOptions) (artifact.Backend, error)
- type Store
- func (s *Store) Delete(ctx context.Context, key string) error
- func (s *Store) Download(ctx context.Context, key string) (io.ReadCloser, *artifact.Metadata, error)
- func (s *Store) Exists(ctx context.Context, key string) (bool, error)
- func (s *Store) GetMetadata(ctx context.Context, key string) (*artifact.Metadata, error)
- func (s *Store) List(ctx context.Context, query artifact.Query) ([]artifact.ArtifactInfo, error)
- func (s *Store) Name() string
- func (s *Store) Upload(ctx context.Context, key string, data io.Reader, size int64, ...) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Store ¶
type Store struct {
// contains filtered or unexported fields
}
Store implements the artifact.Backend interface using GitHub Actions Artifacts.
func (*Store) Download ¶
func (s *Store) Download(ctx context.Context, key string) (io.ReadCloser, *artifact.Metadata, error)
Download downloads an artifact and extracts the tar stream from the zip.
func (*Store) GetMetadata ¶
GetMetadata retrieves metadata for an artifact.
func (*Store) Upload ¶
func (s *Store) Upload(ctx context.Context, key string, data io.Reader, size int64, metadata *artifact.Metadata) error
Upload uploads a single data stream as a GitHub artifact. Creates a zip containing archive.tar (the data stream) + metadata.json. This requires running within GitHub Actions with ACTIONS_RUNTIME_TOKEN and ACTIONS_RESULTS_URL environment variables set.
Click to show internal directories.
Click to hide internal directories.